/**
 *
 */
package net.gorry.aicia;

import android.content.Context;
import android.content.SharedPreferences;
import android.util.Log;

/**
 *
 * IRCﾁｬﾝﾈﾙ設定の読み書き処理
 *
 * @author GORRY
 *
 */
public class IRCChannelConfig {
	private static final String TAG = "IRCServerConfig";
	private static final boolean V = false;

	private final Context me;

	/** サブログに出すならtrue */
	public boolean mPutOnSublog;

	/** 常にサブログに出すならtrue */
	public boolean mPutOnSublogAll;

	/** アラートを出すならtrue */
	public boolean mUseAlert;

	/** 常にアラート扱いにするならtrue */
	public boolean mUseAlertAll;

	/**
	 * コンストラクタ
	 * @param context コンテキスト
	 */
	public IRCChannelConfig(final Context context) {
		if (V) Log.v(TAG, "IRCChannelConfig()");
		me = context;
	}

	/**
	 * 設定読み込み
	 * @param serverId サーバ設定ID
	 * @param channelName チャンネル名
	 */
	public void loadConfig(final int serverId, final String channelName) {
		if (V) Log.v(TAG, "loadConfig()");
		final String id = serverId + ":" + channelName;
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		mPutOnSublog = pref.getBoolean(id + ":putonsublog", true);
		mPutOnSublogAll = pref.getBoolean(id + ":putonsublogall", false);
		mUseAlert = pref.getBoolean(id + ":usealert", true);
		mUseAlertAll = pref.getBoolean(id + ":usealertall", false);
	}

	/**
	 * 設定をコピー
	 * @param from コピー元
	 */
	public void copy(final IRCChannelConfig from) {
		if (V) Log.v(TAG, "copy()");
		mPutOnSublog = from.mPutOnSublog;
		mPutOnSublogAll = from.mPutOnSublogAll;
		mUseAlert = from.mUseAlert;
		mUseAlertAll = from.mUseAlertAll;
	}

	/**
	 * 設定を比較
	 * @param from 比較元
	 * @return 同じならtrue
	 */
	public boolean compare(final IRCChannelConfig from) {
		if (V) Log.v(TAG, "compare()");
		if (mPutOnSublog != from.mPutOnSublog) return false;
		if (mPutOnSublogAll != from.mPutOnSublogAll) return false;
		if (mUseAlert != from.mUseAlert) return false;
		if (mUseAlertAll != from.mUseAlertAll) return false;
		return true;
	}

	/**
	 * 設定保存
	 * @param serverId サーバ設定ID
	 * @param channelName チャンネル名
	 */
	public void saveConfig(final int serverId, final String channelName) {
		if (V) Log.v(TAG, "saveConfig()");
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		final String id = serverId + ":" + channelName;
		final SharedPreferences.Editor editor = pref.edit();
		editor.putBoolean(id + ":putonsublog", mPutOnSublog);
		editor.putBoolean(id + ":putonsublogall", mPutOnSublogAll);
		editor.putBoolean(id + ":usealert", mUseAlert);
		editor.putBoolean(id + ":usealertall", mUseAlertAll);
		editor.commit();
	}

	/**
	 * 設定消去
	 * @param serverId サーバ設定ID
	 * @param channelName チャンネル設定ID
	 */
	public void deleteConfig(final int serverId, final String channelName) {
		if (V) Log.v(TAG, "deleteConfig()");
		final SharedPreferences pref = me.getSharedPreferences("ircserver", 0);
		final String id = serverId + ":" + channelName;
		final SharedPreferences.Editor editor = pref.edit();
		editor.remove(id + ":putonsublog");
		editor.remove(id + ":putonsublogall");
		editor.remove(id + ":usealert");
		editor.remove(id + ":usealertall");
		editor.commit();
	}


}
